package VISD; # $Id: VISD.pm 93 2020-09-25 13:47:07Z abalama $
use warnings;
use strict;
use utf8;

=encoding utf8

=head1 NAME

VISD - VISD Is Status Dashboard

=head1 VERSION

Version 1.01

=head1 SYNOPSIS

    use VISD;

=head1 DESCRIPTION

VISD Is Status Dashboard

=head2 SHARED CONSTANTS

=over 4

=item DEFAULT_HOSTNAME

Default hostname

=item DEFAULT_SOURCE_TYPE

Default source type (remote)

=item VISD_BANNER

Project's Banner

=item VISD_FULL_VERSION

Current project version (full notation)

=item VISD_KEY_PFX

Return key prefix

=item VISD_REVISION

Current project revision

=item VISD_VERSION

Current project version

=back

=head2 NOT IMPORTED CONSTANTS

=over 4

=item BANNER_TPL

Template of the banner

=item DAEMONMAME

Name of Daemon

=item GROUPNAME

Groupname for daemon

=item LAST_DATA_FILE

File name of container with last data

=item PROJECTNAME

Project name

=item PROJECTNAMEL

Project name in lower case

=item SERIALIZER_ATTRS

CTK::Serializer attributes

=item USERNAME

Username for daemon

=back

=head1 HISTORY

See C<Changes> file

=head1 DEPENDENCIES

L<CTK>

=head1 TO DO

See C<TODO> file

=head1 BUGS

* none noted

=head1 SEE ALSO

L<CTK>

=head1 AUTHOR

Serż Minus (Sergey Lepenkov) L<http://www.serzik.com> E<lt>abalama@cpan.orgE<gt>

=head1 COPYRIGHT

Copyright (C) 1998-2020 D&D Corporation. All Rights Reserved

=head1 LICENSE

This program is free software; you can redistribute it and/or
modify it under the same terms as Perl itself.

See C<LICENSE> file and L<https://dev.perl.org/licenses/>

=cut

use vars qw/$VERSION $REVISION @EXPORT @EXPORT_OK/;
$VERSION = '1.01';
$REVISION = q/$Revision: 93 $/ =~ /(\d+\.?\d*)/ ? $1 : '0';

use Sys::Hostname;

@EXPORT = (qw/
        DEFAULT_HOSTNAME
        DEFAULT_SOURCE_TYPE
        VISD_VERSION
        VISD_REVISION
        VISD_FULL_VERSION
        VISD_BANNER
        VISD_KEY_PFX
    /);
@EXPORT_OK = (@EXPORT, qw/
        PROJECTNAME PROJECTNAMEL
        DAEMONMAME
        USERNAME GROUPNAME
        BANNER_TPL
        IS_WIN32
        SERIALIZER_FORMAT SERIALIZER_ATTRS
        LAST_DATA_FILE
    /);

use constant {
        PROJECTNAME         => 'VISD',
        PROJECTNAMEL        => 'visd',
        DAEMONMAME          => 'cetus',
        IS_WIN32            => ($^O =~ /Cygwin|Win32/i ? 1 : 0),
        DEFAULT_HOSTNAME    => "localhost",
        DEFAULT_SOURCE_TYPE => "remote",

        # UID/GID for daemon
        USERNAME            => 'cetus',
        GROUPNAME           => 'cetus',

        # Banner
        BANNER_TPL          => '%s/%s.%d (%s)',
        VERSION_TPL         => '%s.%d',

        # CTK::Serializer
        SERIALIZER_FORMAT   => "json",
        SERIALIZER_ATTRS    => {
            json => [
                { # For serialize
                    utf8 => 0,
                    pretty => 0, # 1 -- pretty!
                    allow_nonref => 1,
                    allow_blessed => 1,
                },
                { # For deserialize
                    utf8 => 0,
                    allow_nonref => 1,
                    allow_blessed => 1,
                },
            ],
        },

        # Files
        LAST_DATA_FILE      => "last_data.json",
};

use base qw/Exporter/;

my $myhostname = undef;

*VISD_VERSION = sub () {
    $VERSION;
};
*VISD_REVISION = sub () {
    $REVISION;
};
*VISD_FULL_VERSION = sub () {
    sprintf(VERSION_TPL, VISD_VERSION(), VISD_REVISION());
};

*VISD_BANNER = sub () {
    $myhostname ||= (hostname() // 'localhost');
    return sprintf(BANNER_TPL,
        PROJECTNAME, VISD_VERSION(), VISD_REVISION(), $myhostname
    );
};

*VISD_KEY_PFX = sub () {
    $myhostname ||= (hostname() // 'localhost');
    return sprintf("%s.%s",
        PROJECTNAMEL, $myhostname,
    );
};

sub _is_web_source {
    my $st = lc(shift || DEFAULT_SOURCE_TYPE);
    return 1 if $st eq DEFAULT_SOURCE_TYPE;
    return 1 if $st eq 'http';
    return 1 if $st eq 'https';
    return 1 if $st eq 'web';
    return 1 if $st eq 'www';
    return 0;
}
sub _explain {
    require Data::Dumper;
    my $dumper = Data::Dumper->new ( [shift] );
    $dumper->Indent(1)->Terse(1);
    $dumper->Sortkeys(1) if $dumper->can("Sortkeys");
    return $dumper->Dump;
}

1;

__END__
